@@ -63,6 +63,7 @@ athena_read.athena_vroom <- function(method, File, athena_types, con, ...){
   
   data_type <- format_athena_types(athena_types)
   Type <- AthenaToRDataType(method, data_type)
+  
   output <- vroom(
     File,
     delim = ",",
@@ -72,6 +73,12 @@ athena_read.athena_vroom <- function(method, File, athena_types, con, ...){
     trim_ws = FALSE,
     altrep = TRUE
   )
+  # timestamp with time zone returns an unusual timestamp format: 
+  # "2021-07-30 14:07:08.008 UTC"
+  # To overcome this return as character and convert afterwards
+  for (col in names(Type[data_type %in% "timestamp with time zone"])){
+    output[[col]] <- as.POSIXct(output[[col]], tz = con@info$timezone)
+  } 
   # convert raw
   if(!identical(athena_option_env$binary, "character"))
     raw_parser(output, data_type)
@@ -142,6 +149,7 @@ athena_read_lines.athena_vroom <- function(method, File, athena_types, con, ...)
   
   data_type <- format_athena_types(athena_types)
   Type <- AthenaToRDataType(method, data_type)
+  
   output <- vroom(
     File,
     col_names = names(Type),
@@ -152,6 +160,12 @@ athena_read_lines.athena_vroom <- function(method, File, athena_types, con, ...)
     trim_ws = FALSE,
     delim = "\n"
   )
+  # timestamp with time zone returns an unusual timestamp format: 
+  # "2021-07-30 14:07:08.008 UTC"
+  # To overcome this return as character and convert afterwards
+  for (col in names(Type[data_type %in% "timestamp with time zone"])){
+    output[[col]] <- as.POSIXct(output[[col]], tz = con@info$timezone)
+  } 
   # convert raw
   if(!identical(athena_option_env$binary, "character"))
     raw_parser(output, data_type)
